%flux balance analysis
%use linear programming to find optimum flux distribution
%adjusted rates (from GMEA) are used to specify lower and upper boundar values
%author Lake-Ee Quek, The University of Queensland, AIBN
%02-Oct-2008

Aeq = stoicMat';
beq = zeros(size(Aeq,1),1);
f = zeros(size(Aeq,2),1);

%fix lower boundar value to 0 if reaction is irreversible
lb=ones(size(Aeq,2),1)*-10000;
ub=ones(size(Aeq,2),1)*10000;
for i = 1:length(rxnTable)
    if rxnTable{i,4}==0
        lb(i)=0;
    end
end

%use adjusted rate to specify lower and upper boundary
lb(rowMea)=rates_hat;
ub(rowMea)=rates_hat;

%objective function
f(2) = -1; %minimize ATP maintenance
[flux,fval,exitflag,output,lambda] = linprog(f,[],[],Aeq,beq,lb,ub);
%check balance (residual)
fprintf('met bal residual:\t%1.3g\n',sum(abs(Aeq*flux)));
if sum(abs(Aeq*flux)) < 1e-3 && exitflag == 1
    disp('optimum flux distribution found')
    pause(1);
    disp('flux results');
    for i = 1:length(rxnTable)
        fprintf('%s:\t%1.5f\n',rxnTable{i,1},flux(i));
    end
else
    disp('optimum not found, check flux solution')
end
